pub struct GraphBuilder { /* private fields */ }Expand description
Builder for constructing dataflow graphs fluently.
Implementations
Sourceimpl GraphBuilder
impl GraphBuilder
Sourcepub fn project(
self,
name: impl Into<String>,
projection_type: impl Into<String>,
) -> Self
pub fn project( self, name: impl Into<String>, projection_type: impl Into<String>, ) -> Self
Add a projection node, connecting from the last node.
Sourcepub fn transform(
self,
name: impl Into<String>,
transform_type: TransformType,
) -> Self
pub fn transform( self, name: impl Into<String>, transform_type: TransformType, ) -> Self
Add a transform node, connecting from the last node.
Sourcepub fn sink(
self,
name: impl Into<String>,
target_property: impl Into<String>,
) -> Self
pub fn sink( self, name: impl Into<String>, target_property: impl Into<String>, ) -> Self
Add a sink node, connecting from the last node.
Sourcepub fn build(self) -> DataflowGraph
pub fn build(self) -> DataflowGraph
Build and return the graph.