Event

Struct Event 

pub struct Event<T> { /* private fields */ }
A stream of discrete occurrences

Event<T> allows you to react to discrete happenings like clicks, keypresses, or timer ticks. Events can be mapped, filtered, and merged with other events.

Example

use cliffy_core::{event, Event};

let clicks = event::<()>();

clicks.subscribe(|_| {
    println!("Clicked!");
});

clicks.emit(());

Implementations

Source

impl<T: Clone + 'static> Event<T>

pub fn new() -> Self

Create a new event stream

pub fn emit(&self, value: T)

Emit a value to all subscribers

pub fn subscribe<F>(&self, callback: F) -> EventSubscription
where F: Fn(&T) + 'static,

Subscribe to this event stream

pub fn map<U, F>(&self, f: F) -> Event<U>
where U: Clone + 'static, F: Fn(T) -> U + 'static,

Map a function over this event stream

pub fn filter<F>(&self, predicate: F) -> Event<T>
where F: Fn(&T) -> bool + 'static,

Filter events based on a predicate

pub fn merge(&self, other: &Event<T>) -> Event<T>

Merge two event streams

pub fn fold<S, F>(&self, initial: S, f: F) -> Behavior<S>
where S: IntoGeometric + FromGeometric + Clone + 'static, F: Fn(S, T) -> S + 'static,

Fold events into a behavior, accumulating values